# AUTOGENERATED FILE
#
# As of autopkgtest 3.5, Ruby packages that use gem2deb are automatically
# detected, and if debian/tests/control does not exist the contents below will
# be assumed (with the exception of gem2deb being filtered out from
# @builddeps@):

Test-Command: gem2deb-test-runner --autopkgtest 2>&1
Depends: @, @builddeps@, gem2deb-test-runner

# if you would need to change something to the above, to that and rename this
# file to `control`. Otherwise, you should probably delete this file
# (recommended).
